
#include <stdlib.h>
#include <math.h>
#include <GL/glut.h>
#include "glm.h"

GLMmodel* pmodel = NULL;
int viewDistorted = 1;


void drawModel(void) {

  if (!pmodel) {
	pmodel = glmReadOBJ("bronco.obj");
	if(!pmodel)
	  exit(0);
	glmUnitize(pmodel);
	glmFacetNormals(pmodel);
	glmVertexNormals(pmodel, 90.0);
  }
  glmDraw(pmodel, GLM_SMOOTH | GLM_MATERIAL);
}

// a non-distored view by making the projection distorted too
void setAspect( int w, int h )
{  
	GLfloat aspect = (GLfloat)w / (GLfloat)h; 

	glViewport(0, 0, w, h);

	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();

	if( viewDistorted )
	  glOrtho(-1.15, 1.15, -1.15, 1.15, -10, 10);
	else 
	{	
		if( aspect > 1.0 )
			glOrtho(-1.15*aspect, 1.15*aspect, -1.15, 1.15, -10, 10);
		else
			glOrtho(-1.15, 1.15, -1.15/aspect, 1.15/aspect, -10, 10);
	}
   glMatrixMode(GL_MODELVIEW);
}
void Reshape(int w, int h) {

  setAspect( w, h ); // a non-distored view by changing ofthe projection

  glMatrixMode(GL_MODELVIEW);
  glLoadIdentity();
  gluLookAt(0.0, 0.25, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);

  glEnable(GL_DEPTH_TEST);
  glShadeModel(GL_SMOOTH);

  glEnable(GL_LIGHTING);
  glEnable(GL_LIGHT0);
}


void Idle(void) {
 
  glRotatef(0.2, 0, 1, 0);
  glutPostRedisplay();
}


void Display(void) {
 GLfloat pos[] = {0.0, 1.0, 1.0, 1.0};

  glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

  glPushMatrix();
  glLoadIdentity();
  glLightfv(GL_LIGHT0, GL_POSITION, pos);
  glPopMatrix();


  glLoadIdentity();
  glRotatef(90, 0,1,0);
  drawModel();


  glutSwapBuffers();  
}


/* keyboard hit causes the program to exit, SPACE changes the viewport aspect */
void Keyboard(unsigned char key, int x, int y) {
	if( key == ' ' )
	{
		viewDistorted = !viewDistorted;
		setAspect( glutGet( GLUT_WINDOW_WIDTH ), glutGet(  GLUT_WINDOW_HEIGHT ) );
		glutPostRedisplay();
	}
	else if( key == 27 )
        exit(0);
}


int main(int argc, char **argv) {

  glutInit(&argc, argv);
  glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGBA);

  glutCreateWindow("Ortho example - press SPACE for transformation aspect change, Esc for exit.");

  glutDisplayFunc(Display);

  glutReshapeFunc(Reshape);
  //glutIdleFunc(Idle);
  glutKeyboardFunc(Keyboard);

  glutMainLoop();

  return 0;
}




